@@ -112,7 +112,7 @@ global_options = {
     '--os-default-domain': (DEFAULT_DOMAIN_NAME, True, True),
     '--os-cacert': ('/dev/null', True, True),
     '--timing': (True, True, False),
-    '--os-profile': ('SECRET_KEY', True, False),
+    '--os-profile': ('SECRET_KEY', True, True),
     '--os-interface': (DEFAULT_INTERFACE, True, True)
 }
 
